@@ -100,7 +100,7 @@ impl<F: ObjFunc> Solver<F> {
                     Adaptive::Constant(ada) => iter.filter(|f| f.value() > ada).count(),
                     Adaptive::Average => iter.filter(|f| f.value() > ctx.report.average).count(),
                     Adaptive::Custom => iter.filter(|f| f.feasible()).count(),
-                    Adaptive::Disable => panic!(),
+                    Adaptive::Disable => unreachable!(),
                 };
                 ctx.report.adaptive = feasible as f64 / ctx.pop_num() as f64;
             }
@@ -122,8 +122,8 @@ impl<F: ObjFunc> Solver<F> {
                     }
                 }
                 #[cfg(feature = "std")]
-                Task::MaxTime(v) => {
-                    if (Instant::now() - time_start).as_secs_f32() >= v {
+                Task::MaxTime(d) => {
+                    if Instant::now() - time_start >= d {
                         break;
                     }
                 }
@@ -137,6 +137,15 @@ impl<F: ObjFunc> Solver<F> {
         Self(ctx)
     }
 
+    /// Get the reference of the objective function.
+    ///
+    /// It's useful when you need to get the preprocessed data from the initialization process,
+    /// which is stored in the objective function.
+    #[inline(always)]
+    pub fn func(&self) -> &F {
+        &self.0.func
+    }
+
     /// Get the history for plotting.
     #[inline(always)]
     pub fn reports(&self) -> Vec<Report> {
