@@ -83,26 +83,32 @@ impl<F: ObjFunc> Context<F> {
     }
 
     pub(crate) fn init_pop(&mut self) {
-        let mut tasks = ThreadPool::new();
-        let mut best = 0;
-        for i in 0..self.pop_num() {
-            for s in 0..self.dim() {
-                self.pool[[i, s]] = rand_float(self.lb(s), self.ub(s));
-            }
-            tasks.insert(
-                i,
-                self.func.clone(),
-                self.report.clone(),
-                self.pool.slice(s![i, ..]),
-            );
+        let pool = Array2::from_shape_fn([self.pop_num(), self.dim()], |(_, s)| {
+            rand_float(self.lb(s), self.ub(s))
+        });
+        let mut fitness = self.fitness.clone();
+        let zip = Zip::from(&mut fitness).and(pool.axis_iter(Axis(0)));
+        #[cfg(not(feature = "parallel"))]
+        {
+            zip.for_each(|f, v| {
+                *f = self.func.fitness(v.to_slice().unwrap(), &self.report);
+            });
+            self.find_best();
         }
-        for (i, f) in tasks {
-            self.fitness[i] = f;
-            if self.fitness[i].value() < self.fitness[best].value() {
-                best = i;
-            }
+        #[cfg(feature = "parallel")]
+        {
+            let (f, v) = zip
+                .into_par_iter()
+                .map(|(f, v)| {
+                    *f = self.func.fitness(v.to_slice().unwrap(), &self.report);
+                    (f.value(), v)
+                })
+                .min_by(|(a, _), (b, _)| a.partial_cmp(b).unwrap())
+                .unwrap();
+            self.set_best_from(f, v);
         }
-        self.set_best(best);
+        self.pool = pool;
+        self.fitness = fitness;
     }
 
     /// Set the index to best.
@@ -113,6 +119,16 @@ impl<F: ObjFunc> Context<F> {
         self.best.assign(&self.pool.slice(s![i, ..]));
     }
 
+    /// Set the fitness and variables to best.
+    #[inline(always)]
+    pub fn set_best_from<'a, A>(&mut self, f: f64, v: A)
+    where
+        A: AsArray<'a, f64>,
+    {
+        self.report.best_f = f;
+        self.best.assign(&v.into());
+    }
+
     /// Assign the index from best.
     #[inline(always)]
     pub fn assign_from_best(&mut self, i: usize) {
